clear

cd "/Users/hyndmank/Dropbox/MS Replication Stuff/MS Replication System Neglect/ReplicationData"

log using "Mich_Log.txt", text replace

import excel using "data_Mich.xlsx", firstr sheet("Worksheet")

egen gsid = group(Session Participant)

rename seedNum demandseed
rename StepgroupLoop period
rename myForecast ft0
rename actualDemand demand
rename myError aerror

tab gsid if condition == 1 & period == 1
tab gsid if condition == 5 & period == 1

sort gsid period
xtset gsid period

gen df = d.ft0
gen ft1 = l.ft0
gen e0 = lastDemand - ft1

gen df0 = l.df
gen df1 = l.df0

gen dd0 = d.demand
gen dd1 = l.dd0

gen funky = (aerror > 300)
order gsid funky period condition demandseed ft0 aerror demand lastDemand df e0 ft1 dd0 dd1 df0 df1

label var e0 "$\mu(E_t)$"
label var ft1 "$F_t$"
label var dd0 "$\mu(\Delta D_t)$"
label var dd1 "\Delta D_{t-1}$"
label var df0 "$\Delta F_t$"
label var df1 "$\Delta F_{t-1}"

*this is Model 4 in Table C.2. The models slightly differ to achieve convergence*
* This is consistent with the approach taken by the original authors. *

mixed df e0 ft1 dd0 dd1 df0 df1 if condition==5 & funky == 0 ||demandseed: e0 dd0 ||gsid: e0 dd0
estimates store condition5
test e0 = 0.94
display r(p)
local ll = e(ll)
display `ll'

mixed df e0 ft1 dd0 dd1 df0 df1 if condition==5 & funky == 0 ||demandseed: dd0 ||gsid: e0 dd0
local ll_e0= e(ll)
display `ll_e0'

mixed df e0 ft1 dd0 dd1 df0 df1 if condition==5 & funky == 0 ||demandseed: e0 ||gsid: e0 dd0
local ll_dd0= e(ll)
display `ll_dd0'

mixed df e0 ft1 dd0 dd1 df0 df1 if condition==5 & funky == 0 ||demandseed: e0 dd0, nocons ||gsid: e0 dd0
local ll_cons= e(ll)
display `ll_cons'

mixed df e0 ft1 dd0 dd1 df0 df1 if condition==5 & funky == 0 ||demandseed: e0 dd0 ||gsid: dd0
local ll_e0_g= e(ll)
display `ll_e0_g'

mixed df e0 ft1 dd0 dd1 df0 df1 if condition==5 & funky == 0 ||demandseed: e0 dd0 ||gsid: e0
local ll_dd0_g= e(ll)
display `ll_dd0_g'

mixed df e0 ft1 dd0 dd1 df0 df1 if condition==5 & funky == 0 ||demandseed: e0 dd0 ||gsid: e0 dd0, nocons
local ll_cons_g= e(ll)
display `ll_cons_g'

local test_e0 = 2*(`ll' - `ll_e0')
display `test_e0'
display 1-chi2(1,`test_e0')

local test_dd0 = 2*(`ll' - `ll_dd0')
display `test_dd0'
display 1-chi2(1,`test_dd0')

local test_cons = 2*(`ll' - `ll_cons')
display `test_cons'
display 1-chi2(1,`test_cons')

local test_e0_g = 2*(`ll' - `ll_e0_g')
display `test_e0_g'
display 1-chi2(1,`test_e0_g')

local test_dd0_g = 2*(`ll' - `ll_dd0_g')
display `test_dd0_g'
display 1-chi2(1,`test_dd0_g')

local test_cons_g = 2*(`ll' - `ll_cons_g')
display `test_cons_g'
display 1-chi2(1,`test_cons_g')

*these commands convert the results from this model into the parameter estimates in Table 4*

*nlcom _b[dd0]/_b[e0]       /* beta */
*nlcom _b[ft1]+1            /* theta_L */
*nlcom _b[_cons]/(_b[ft1])  /* constant */

/* Note that the below command would be the "true" estimation based on the author's preferred specification. However, when we estimate it, we do not achieve convergence. This was also the case in the original paper. Therefore, we replicated their actual analysis below.
** doesn't converge
*mixed df e0 ft1 dd0 dd1 df0 df1 if condition==1 ||demandseed: e0 dd0 ||gsid: e0 dd0, reml
*test e0 = 0
*/

* Doing what Enno did
mixed df e0 ft1 dd0 dd1 df0 df1 if condition==1 & funky==0 ||gsid: e0 dd0
estimates store condition1
test e0 = 0
display r(p)
local ll = e(ll)
display `ll'

mixed df e0 ft1 dd0 dd1 df0 df1 if condition==1 & funky == 0 ||gsid: dd0
local ll_e0_g= e(ll)
display `ll_e0_g'
mixed df e0 ft1 dd0 dd1 df0 df1 if condition==1 & funky == 0 ||gsid: e0
local ll_dd0_g= e(ll)
display `ll_dd0_g'
mixed df e0 ft1 dd0 dd1 df0 df1 if condition==1 & funky == 0 ||gsid: e0 dd0, nocons
local ll_cons_g= e(ll)
display `ll_cons_g'

local test_e0_g = 2*(`ll' - `ll_e0_g')
display `test_e0_g'
display 1-chi2(1,`test_e0_g')

local test_dd0_g = 2*(`ll' - `ll_dd0_g')
display `test_dd0_g'
display 1-chi2(1,`test_dd0_g')

local test_cons_g = 2*(`ll' - `ll_cons_g')
display `test_cons_g'
display 1-chi2(1,`test_cons_g')

*these commands convert the results from this model into the parameter estimates in Table 4*

*nlcom _b[dd0]/_b[e0]       /* beta */
*nlcom _b[ft1]+1            /* theta_L */
*nlcom _b[_cons]/(_b[ft1])  /* constant */

local fmtpc = "%4.1f" // formatting for percentages
local fmtint = "%8.0f" // formatting for integers (probably unnecessary if typed as byte/int)
local fmtpval = "%8.3f" // formatting for p-values
local fmtprop = "%8.2f" // formatting for proportions
local fmtcurr = "%9.2f" // formatting for currency
local fmtavpts = "%8.1f" // formatting for averaged points (i.e. averaged integers)

**** set local for significance stars in regression tables
local sigstars `"star(* 0.1 ** 0.05 *** 0.01)"'

esttab condition1 condition5 ///
	using "Mich_Table" ///
	, b(%10.3f) `sigstars' se(%10.3f) margin discrete("") obslast stat(r2_o N)  sfmt(`fmtprop' `fmtint') /// 
	label nomtitles nonumbers eql("") nolines nonotes nogaps wide booktabs compress fragment constant replace
